==> foswiki-1.1.3.tbz: www/foswiki/lib/Foswiki/Macros/FORMFIELD.pm <==
# See bottom of file for license and copyright information
package Foswiki;

use strict;
use warnings;

sub FORMFIELD {
    my ( $this, $args, $topicObject ) = @_;
    if ( $args->{topic} ) {
        my ( $web, $topic ) =
          $this->normalizeWebTopicName( $topicObject->web, $args->{topic} );
        $topicObject = new Foswiki::Meta( $this, $web, $topic );
    }
    else {

        # SMELL: horrible hack; assumes the current rev comes from the 'rev'
        # parameter. There has to be a better way!
        my $query = $this->{request};
        $args->{rev} ||= $query->param('rev') if ($query);
    }
    return $this->renderer->renderFORMFIELD( $args, $topicObject );
}

1;

__END__
Foswiki - The Free and Open Source Wiki, http://foswiki.org/

Copyright (C) 2008-2009 Foswiki Contributors. Foswiki Contributors
are listed in the AUTHORS file in the root of this distribution.
NOTE: Please extend that file, not this notice.

Additional copyrights apply to some or all of the code in this
file as follows:

Copyright (C) 1999-2007 Peter Thoeny, peter@thoeny.org
and TWiki Contributors. All Rights Reserved. TWiki Contributors
are listed in the AUTHORS file in the root of this distribution.
Based on parts of Ward Cunninghams original Wiki and JosWiki.
Copyright (C) 1998 Markus Peter - SPiN GmbH (warpi@spin.de)
Some changes by Dave Harris (drh@bhresearch.co.uk) incorporated

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version. For
more details read LICENSE in the root of this distribution.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

As per the GPL, removal of this notice is prohibited.

==> foswiki-1.1.5.tbz: www/foswiki/lib/Foswiki/Macros/FORMFIELD.pm <==
# See bottom of file for license and copyright information
package Foswiki;

use strict;
use warnings;

sub FORMFIELD {
    my ( $this, $args, $topicObject ) = @_;
    if ( $args->{topic} ) {
        my $web = $args->{web} || $topicObject->web;
        my $topic = $args->{topic};
        ( $web, $topic ) = $this->normalizeWebTopicName( $web, $topic );
        $topicObject = new Foswiki::Meta( $this, $web, $topic );
    }
    else {

        # SMELL: horrible hack; assumes the current rev comes from the 'rev'
        # parameter. There has to be a better way!
        my $query = $this->{request};
        my $cgiRev;
        $cgiRev = $query->param('rev') if ($query);
        $args->{rev} = Foswiki::Store::cleanUpRevID( $args->{rev} || $cgiRev ) || '';
    }
    return $this->renderer->renderFORMFIELD( $args, $topicObject );
}

1;

__END__
Foswiki - The Free and Open Source Wiki, http://foswiki.org/

Copyright (C) 2008-2009 Foswiki Contributors. Foswiki Contributors
are listed in the AUTHORS file in the root of this distribution.
NOTE: Please extend that file, not this notice.

Additional copyrights apply to some or all of the code in this
file as follows:

Copyright (C) 1999-2007 Peter Thoeny, peter@thoeny.org
and TWiki Contributors. All Rights Reserved. TWiki Contributors
are listed in the AUTHORS file in the root of this distribution.
Based on parts of Ward Cunninghams original Wiki and JosWiki.
Copyright (C) 1998 Markus Peter - SPiN GmbH (warpi@spin.de)
Some changes by Dave Harris (drh@bhresearch.co.uk) incorporated

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version. For
more details read LICENSE in the root of this distribution.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

As per the GPL, removal of this notice is prohibited.
